pub fn get_python_exec_path(venv_path: &PathBuf) -> PathBufExpand description
Returns the path of the Python executable within the given virtual environment.
For Unix-like systems (Linux, macOS), the Python executable is located in the bin directory.
For Windows, the Python executable is located in the Scripts directory, and has the .exe extension.