pub fn get_uv_path() -> Result<String>Expand description
Find the path of the uv command.
The function returns Ok<String> if uv is found, where the string is the path of
the uv command. If uv is not found, the function prints a hint to install it
and returns an Err.
The function uses which or where command to find the path of uv. If the command
is not successful, it means uv is not installed, so the function prints a hint to
install it and returns an Err.
Errors
The function returns an Err if uv is not installed.