get_python_native_path

Function get_python_native_path 

pub fn get_python_native_path(uv_path: &String) -> String
Finds the native Python executable path.

If uv_path is empty, it uses which or where command to find the native Python executable. If the command is successful, it returns the path of the Python executable. If the command is not successful, it returns an empty string.

If uv_path is not empty, it returns an empty string.

Platform-specific

On Unix-like systems, it uses which command.

On Windows, it uses where command.